@@ -1,7 +1,7 @@
-# Copyright 2014 SAP AG or an SAP affiliate company.
+# Copyright 2015 SAP AG or an SAP affiliate company.
 # 
 
-__version__ = '1.0.1'
+__version__ = '1.0.3'
 
 from sqlalchemy_sqlany import base
 
@@ -13,7 +13,7 @@ from .base import CHAR, VARCHAR, TIME, NCHAR, NVARCHAR,\
                  BIGINT, INT, INTEGER, SMALLINT, BINARY,\
                  VARBINARY, UNITEXT, UNICHAR, UNIVARCHAR,\
                  IMAGE, BIT, MONEY, SMALLMONEY, TINYINT,\
-                 dialect
+                 dialect, SQLAnyNoPrimaryKeyError
 
 
 __all__ = (
@@ -22,5 +22,5 @@ __all__ = (
     'BIGINT', 'INT', 'INTEGER', 'SMALLINT', 'BINARY',
     'VARBINARY', 'UNITEXT', 'UNICHAR', 'UNIVARCHAR',
     'IMAGE', 'BIT', 'MONEY', 'SMALLMONEY', 'TINYINT',
-    'dialect'
+    'dialect', "SQLAnyNoPrimaryKeyError"
 )
